@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 3.0.0 $
+### $Release: 3.0.1 $
 ### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
-### $License: MIT License $
+### $License: Public Domain $
 ###
 
 import sys, os, re, time, gc
@@ -21,7 +21,7 @@ if python3:
     from io import StringIO
 
 __all__     = ('Benchmarker', )
-__version__ = "$Release: 3.0.0 $".split(' ')[1]
+__version__ = "$Release: 3.0.1 $".split(' ')[1]
 
 
 class Format(object):
@@ -393,7 +393,7 @@ class Task(object):
     def __init__(self, result, loop=1, _empty=None):
         #: takes a Result object, loop, and _empty result.
         self.result = result
-        self.loop   = loop
+        self.loop   = loop or 1
         self._empty = _empty
 
     def __enter__(self):
@@ -461,11 +461,11 @@ class Task(object):
         try:
             #: executes block for N times if 'loop' is specified.
             if loop > 1:
-                for i in xrange(loop):
+                for i in xrange(1, loop+1):
                     yield i
-            #: executes block only once if 'loop' is not specified..
+            #: executes block only once if 'loop' is not specified.
             else:
-                yield i
+                yield 1
         except Exception:
             raised = True
         #: calls __exit__() to simulate with-statement.
