@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 ###
-### $Release: 3.0.0 $
+### $Release: 3.0.1 $
 ### $Copyright: copyright(c) 2010-2011 kuwata-lab.com all rights reserved $
-### $License: MIT License $
+### $License: Public Domain $
 ###
 
 from __future__ import with_statement
@@ -762,13 +762,18 @@ class Task_TC(object):
         count = 0
         for _ in task:
             count += 1
-            ok (_) == count - 1
+            ok (_) == count
         with spec("calls __enter__() to simulate with-statement."):
             ok (tr[0]) == [task, '__enter__', (), {}, task]
         with spec("executes block for N times if 'loop' is specified."):
             ok (count) == 3
         with spec("executes block only once if 'loop' is not specified.."):
-            pass
+            task2 = self._new_task("SOS2", None)
+            cnt2 = 0
+            for _ in task2:
+                cnt2 += 1
+                ok (_) == cnt2
+            ok (cnt2) == 1
         with spec("calls __exit__() to simulate with-statement."):
             ok (tr[1]) == [task, '__exit__', (None, None, None), {}, None]
 
